==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/settings/l10n/bn_BD.php <==
<?php
$TRANSLATIONS = array(
"Email sent" => "ই-মেইল পাঠানো হয়েছে",
"Encryption" => "সংকেতায়ন",
"Unable to load list from App Store" => "অ্যাপস্টোর থেকে তালিকা লোড করতে সক্ষম নয়",
"Authentication error" => "অনুমোদন ঘটিত সমস্যা",
"Group already exists" => "গোষ্ঠীটি পূর্ব থেকেই বিদ্যমান",
"Unable to add group" => "গোষ্ঠী যোগ করা সম্ভব হলো না",
"Email saved" => "ই-মেইল সংরক্ষন করা হয়েছে",
"Invalid email" => "ই-মেইলটি সঠিক নয়",
"Unable to delete group" => "গোষ্ঠী মুছে ফেলা সম্ভব হলো না ",
"Unable to delete user" => "ব্যবহারকারী মুছে ফেলা সম্ভব হলো না ",
"Language changed" => "ভাষা পরিবর্তন করা হয়েছে",
"Invalid request" => "অনুরোধটি সঠিক নয়",
"Admins can't remove themself from the admin group" => "প্রশাসকবৃন্দ তাদেরকে প্রশাসক গোষ্ঠী থেকে মুছে ফেলতে পারবেন না",
"Unable to add user to group %s" => " %s গোষ্ঠীতে ব্যবহারকারী যোগ করা সম্ভব হলো না ",
"Unable to remove user from group %s" => "%s গোষ্ঠী থেকে ব্যবহারকারীকে অপসারণ করা সম্ভব হলো না",
"User Documentation" => "ব্যবহারকারী সহায়িকা",
"Disable" => "নিষ্ক্রিয়",
"Enable" => "সক্রিয় ",
"Error" => "সমস্যা",
"Update" => "পরিবর্ধন",
"undo" => "ক্রিয়া প্রত্যাহার",
"Groups" => "গোষ্ঠীসমূহ",
"Group Admin" => "গোষ্ঠী প্রশাসক",
"Delete" => "মুছে",
"never" => "কখনোই নয়",
"__language_name__" => "__language_name__",
"None" => "কোনটিই নয়",
"Login" => "প্রবেশ",
"Security Warning" => "নিরাপত্তাজনিত সতর্কতা",
"Server address" => "সার্ভার ঠিকানা",
"Port" => "পোর্ট",
"More" => "বেশী",
"Less" => "কম",
"Version" => "ভার্সন",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "তৈলী করেছেন <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud সম্প্রদায়</a>, যার <a href=\"https://github.com/owncloud\" target=\"_blank\"> উৎস কোডটি <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> এর অধীনে লাইসেন্সকৃত।",
"Add your App" => "আপনার অ্যাপটি যোগ করুন",
"More Apps" => "আরও অ্যাপ",
"Select an App" => "অ্যাপ নির্বাচন করুন",
"See application page at apps.owncloud.com" => "apps.owncloud.com এ অ্যাপ্লিকেসন পৃষ্ঠা দেখুন",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-লাইসেন্সধারী <span class=\"author\"></span>",
"Administrator Documentation" => "প্রশাসক সহায়িকা",
"Online Documentation" => "অনলাইন সহায়িকা",
"Forum" => "ফোরাম",
"Bugtracker" => "বাগট্র্যাকার",
"Commercial Support" => "বাণিজ্যিক সাপোর্ট",
"Show First Run Wizard again" => "প্রথমবার চালানোর যাদুকর পূনরায় প্রদর্শন কর",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "আপনি ব্যবহার করছেন  <strong>%s</strong>, সুলভ  <strong>%s</strong> এর মধ্যে।",
"Password" => "কূটশব্দ",
"Your password was changed" => "আপনার কূটশব্দটি পরিবর্তন করা হয়েছে ",
"Unable to change your password" => "আপনার কূটশব্দটি পরিবর্তন করতে সক্ষম নয়",
"Current password" => "বর্তমান কূটশব্দ",
"New password" => "নতুন কূটশব্দ",
"Change password" => "কূটশব্দ পরিবর্তন করুন",
"Email" => "ইমেইল",
"Your email address" => "আপনার ই-মেইল ঠিকানা",
"Cancel" => "বাতির",
"Language" => "ভাষা",
"Help translate" => "অনুবাদ করতে সহায়তা করুন",
"Login Name" => "প্রবেশ",
"Create" => "তৈরী কর",
"Unlimited" => "অসীম",
"Other" => "অন্যান্য",
"Username" => "ব্যবহারকারী",
"Default" => "পূর্বনির্ধারিত"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/settings/l10n/bn_BD.php <==
<?php
$TRANSLATIONS = array(
"Email sent" => "ই-মেইল পাঠানো হয়েছে",
"Encryption" => "সংকেতায়ন",
"Unable to load list from App Store" => "অ্যাপস্টোর থেকে তালিকা লোড করতে সক্ষম নয়",
"Authentication error" => "অনুমোদন ঘটিত সমস্যা",
"Group already exists" => "গোষ্ঠীটি পূর্ব থেকেই বিদ্যমান",
"Unable to add group" => "গোষ্ঠী যোগ করা সম্ভব হলো না",
"Email saved" => "ই-মেইল সংরক্ষন করা হয়েছে",
"Invalid email" => "ই-মেইলটি সঠিক নয়",
"Unable to delete group" => "গোষ্ঠী মুছে ফেলা সম্ভব হলো না ",
"Unable to delete user" => "ব্যবহারকারী মুছে ফেলা সম্ভব হলো না ",
"Language changed" => "ভাষা পরিবর্তন করা হয়েছে",
"Invalid request" => "অনুরোধটি সঠিক নয়",
"Admins can't remove themself from the admin group" => "প্রশাসকবৃন্দ তাদেরকে প্রশাসক গোষ্ঠী থেকে মুছে ফেলতে পারবেন না",
"Unable to add user to group %s" => " %s গোষ্ঠীতে ব্যবহারকারী যোগ করা সম্ভব হলো না ",
"Unable to remove user from group %s" => "%s গোষ্ঠী থেকে ব্যবহারকারীকে অপসারণ করা সম্ভব হলো না",
"User Documentation" => "ব্যবহারকারী সহায়িকা",
"Disable" => "নিষ্ক্রিয়",
"Enable" => "সক্রিয় ",
"Error" => "সমস্যা",
"Update" => "পরিবর্ধন",
"undo" => "ক্রিয়া প্রত্যাহার",
"Groups" => "গোষ্ঠীসমূহ",
"Group Admin" => "গোষ্ঠী প্রশাসক",
"Delete" => "মুছে",
"never" => "কখনোই নয়",
"__language_name__" => "__language_name__",
"None" => "কোনটিই নয়",
"Login" => "প্রবেশ",
"Security Warning" => "নিরাপত্তাজনিত সতর্কতা",
"Server address" => "সার্ভার ঠিকানা",
"Port" => "পোর্ট",
"More" => "বেশী",
"Less" => "কম",
"Version" => "ভার্সন",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "তৈলী করেছেন <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud সম্প্রদায়</a>, যার <a href=\"https://github.com/owncloud\" target=\"_blank\"> উৎস কোডটি <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> এর অধীনে লাইসেন্সকৃত।",
"Add your App" => "আপনার অ্যাপটি যোগ করুন",
"More Apps" => "আরও অ্যাপ",
"Select an App" => "অ্যাপ নির্বাচন করুন",
"See application page at apps.owncloud.com" => "apps.owncloud.com এ অ্যাপ্লিকেসন পৃষ্ঠা দেখুন",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-লাইসেন্সধারী <span class=\"author\"></span>",
"Administrator Documentation" => "প্রশাসক সহায়িকা",
"Online Documentation" => "অনলাইন সহায়িকা",
"Forum" => "ফোরাম",
"Bugtracker" => "বাগট্র্যাকার",
"Commercial Support" => "বাণিজ্যিক সাপোর্ট",
"Show First Run Wizard again" => "প্রথমবার চালানোর যাদুকর পূনরায় প্রদর্শন কর",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "আপনি ব্যবহার করছেন  <strong>%s</strong>, সুলভ  <strong>%s</strong> এর মধ্যে।",
"Password" => "কূটশব্দ",
"Your password was changed" => "আপনার কূটশব্দটি পরিবর্তন করা হয়েছে ",
"Unable to change your password" => "আপনার কূটশব্দটি পরিবর্তন করতে সক্ষম নয়",
"Current password" => "বর্তমান কূটশব্দ",
"New password" => "নতুন কূটশব্দ",
"Change password" => "কূটশব্দ পরিবর্তন করুন",
"Email" => "ইমেইল",
"Your email address" => "আপনার ই-মেইল ঠিকানা",
"Cancel" => "বাতির",
"Language" => "ভাষা",
"Help translate" => "অনুবাদ করতে সহায়তা করুন",
"Login Name" => "প্রবেশ",
"Create" => "তৈরী কর",
"Unlimited" => "অসীম",
"Other" => "অন্যান্য",
"Username" => "ব্যবহারকারী",
"Default" => "পূর্বনির্ধারিত",
"No problems found" => "কোন সমস্যা পাওয়া গেল না",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
